/* Copyright (c) The m-m-m Team, Licensed under the Apache License, Version 2.0
 * http://www.apache.org/licenses/LICENSE-2.0 */
package net.sf.mmm.util.validation.base;

import java.util.Date;
import java.util.regex.Pattern;

import net.sf.mmm.util.NlsBundleUtilCoreRoot;
import net.sf.mmm.util.nls.api.NlsMessage;

/**
 * This is a {@link net.sf.mmm.util.validation.api.ValueValidator} that {@link #validate(String) validates
 * that a value} matches a given pattern.
 * 
 * @author Joerg Hohwiller (hohwille at users.sourceforge.net)
 * @since 3.1.0
 */
public class ValidatorRegexPattern extends AbstractValueValidator<String> {

  /** @see #validateNotNull(Date) */
  private final Pattern pattern;

  /**
   * The constructor.
   * 
   * @param regex is the regular expression {@link Pattern}.
   */
  public ValidatorRegexPattern(String regex) {

    super();
    this.pattern = Pattern.compile(regex);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  protected NlsMessage validateNotNull(String value) {

    if (this.pattern.matcher(value).matches()) {
      return null;
    }
    // TODO hohwille create proper message...
    return createBundle(NlsBundleUtilCoreRoot.class)
        .errorParseFormat(value, this.pattern.pattern(), String.class, null);
  }

}
